@@ -1,7 +1,7 @@
 #!/usr/bin/python3
 
-from lintian_brush.deb822 import Deb822Updater
-from lintian_brush.fixer import report_result
+from debmutate.deb822 import Deb822Editor
+from lintian_brush.fixer import report_result, warn
 import sys
 
 try:
@@ -18,11 +18,23 @@ typo_fixed = set()
 case_fixed = set()
 
 try:
-    with Deb822Updater('debian/copyright') as updater:
+    with Deb822Editor('debian/copyright') as updater:
         for paragraph in updater.paragraphs:
             for field in paragraph:
                 if field in valid_field_names:
                     continue
+                if (field.startswith('X-') and
+                        field[2:] in valid_field_names):
+                    if field[2:] in paragraph:
+                        warn('Both %s and %s exist.' % (
+                             field, field[2:]))
+                        continue
+                    value = paragraph[field]
+                    del paragraph[field]
+                    paragraph[field[2:]] = value
+                    typo_fixed.add((field, field[2:]))
+                    continue
+
                 for option in valid_field_names:
                     if distance(field, option) == 1:
                         value = paragraph[field]
