@@ -3,6 +3,7 @@
 import sys
 
 from debmutate.control import ControlEditor
+from lintian_brush.fixer import report_result, fixed_lintian_tag
 from lintian_brush.standards_version import (
     parse_standards_version,
     iter_standards_versions,
@@ -21,9 +22,11 @@ with ControlEditor() as updater:
         sys.exit(0)
     if sv[:3] in release_dates:
         sys.exit(0)
+    invalid_version = updater.source['Standards-Version']
+    fixed_lintian_tag('source', 'invalid-standards-version', invalid_version)
     if len(sv) == 2 and (sv[0], sv[1], 0) in release_dates:
         updater.source['Standards-Version'] += '.0'
-        print("Add missing .0 suffix in Standards-Version.")
+        report_result("Add missing .0 suffix in Standards-Version.")
     elif sv > sorted(release_dates)[-1]:
         # Maybe we're just unaware of new policy releases?
         sys.exit(0)
@@ -32,9 +35,7 @@ with ControlEditor() as updater:
         candidates = [v for v in release_dates if v < sv]
         newsv = sorted(candidates)[-1]
         newsv_str = '.'.join([str(x) for x in newsv])
-        print('Replace invalid standards version %s with valid %s.' % (
-              updater.source['Standards-Version'], newsv_str))
+        report_result(
+            'Replace invalid standards version %s with valid %s.' % (
+                updater.source['Standards-Version'], newsv_str))
         updater.source['Standards-Version'] = newsv_str
-
-
-print('Fixed-Lintian-Tags: invalid-standards-version')
