@@ -1,6 +1,7 @@
 #!/usr/bin/python3
 
 from lintian_brush.systemd import systemd_service_files, SystemdServiceEditor
+from lintian_brush.fixer import report_result
 
 for path in systemd_service_files():
     with SystemdServiceEditor(path) as updater:
@@ -11,5 +12,6 @@ for path in systemd_service_files():
             pass
 
 
-print('Rename BindTo key to BindsTo in systemd files.')
-print('Fixed-Lintian-Tags: systemd-service-file-refers-to-obsolete-bindto')
+report_result(
+    'Rename BindTo key to BindsTo in systemd files.',
+    fixed_lintian_tags=['systemd-service-file-refers-to-obsolete-bindto'])
