@@ -1,6 +1,7 @@
 #!/usr/bin/python3
 
 from lintian_brush.systemd import systemd_service_files, SystemdServiceEditor
+from lintian_brush.fixer import report_result
 
 DEPRECATED_TARGETS = ['syslog.target']
 
@@ -18,7 +19,8 @@ for path in systemd_service_files():
 
 removed.sort()
 
-print('Remove references to obsolete targets in systemd unit files: %s.' %
-      ', '.join(['%s (%s)' % (filename, target)
-                for (filename, target) in removed]))
-print('Fixed-Lintian-Tags: systemd-service-file-refers-to-obsolete-target')
+report_result(
+    'Remove references to obsolete targets in systemd unit files: %s.' %
+    ', '.join(['%s (%s)' % (filename, target)
+               for (filename, target) in removed]),
+    fixed_lintian_tags=['systemd-service-file-refers-to-obsolete-target'])
