@@ -1,12 +1,13 @@
 #!/usr/bin/python3
 
-from lintian_brush.control import ControlUpdater
+from debmutate.control import ControlEditor
+
 from lintian_brush.fixer import report_result
 
 packages = []
 
 
-with ControlUpdater() as updater:
+with ControlEditor() as updater:
     default_priority = updater.source.get("Priority")
 
     # TODO(jelmer): needs higher certainty?
