@@ -13,8 +13,10 @@ from lintian_brush.fixer import (
     package_is_native,
     meets_minimum_certainty,
     net_access_allowed,
+    override_exists,
     report_result,
     trust_package,
+    fixed_lintian_tag,
     )
 from lintian_brush.upstream_metadata import (
     UpstreamDatum,
@@ -34,7 +36,18 @@ from lintian_brush.yaml import (
     )
 
 
-fixed_tags = []
+def filter_by_tag(orig, changed, fields, tag):
+    if all(field in orig for field in fields):
+        return
+
+    if (not all(field in orig for field in fields) and
+            override_exists('source', tag)):
+        for field in fields:
+            if field in changed:
+                del changed[field]
+
+    if all(field in orig or field in changed for field in fields):
+        fixed_lintian_tag('source', tag)
 
 
 if package_is_native():
@@ -44,10 +57,19 @@ if package_is_native():
 
 current_version = current_package_version()
 
+if not os.path.exists('debian/upstream/metadata') and override_exists(
+        'source', tag='upstream-metadata-file-is-missing'):
+    sys.exit(0)
+
+
+with YamlUpdater('debian/upstream/metadata') as editor:
+    if isinstance(editor.code, str):
+        sys.exit(0)
 
-with YamlUpdater('debian/upstream/metadata') as code:
     upstream_metadata = {
-        k: UpstreamDatum(k, v, 'certain') for (k, v) in code.items()}
+        k: UpstreamDatum(k, v, 'certain')
+        for (k, v) in editor.code.items()
+        if v is not None}
 
     minimum_certainty = os.environ.get('MINIMUM_CERTAINTY')
     net_access = net_access_allowed()
@@ -103,36 +125,37 @@ with YamlUpdater('debian/upstream/metadata') as code:
     changed = {
         k: v
         for k, v in upstream_metadata.items()
-        if v.value != code.get(k)}
+        if v.value != editor.code.get(k)}
 
     if not changed:
         sys.exit(0)
 
-    if (('Repository' in changed and 'Repository' not in code) or
-            ('Repository-Browse' in changed and
-                'Repository-Browse' not in code)):
-        fixed_tags.append('upstream-metadata-missing-repository')
+    filter_by_tag(
+        editor.code, changed,
+        ['Repository', 'Repository-Browse'],
+        'upstream-metadata-missing-repository')
 
-    if (('Bug-Database' in changed and 'Bug-Database' not in code) or
-            ('Bug-Submit' in changed and 'But-Submit' not in code)):
-        fixed_tags.append('upstream-metadata-missing-bug-tracking')
+    filter_by_tag(
+        editor.code, changed,
+        ['Bug-Database', 'Bug-Submit'],
+        'upstream-metadata-missing-bug-tracking')
 
     # A change that just says the "Name" field is a bit silly
     if set(changed.keys()) - set(ADDON_ONLY_FIELDS) == set(['Name']):
         sys.exit(0)
 
     if not os.path.exists('debian/upstream/metadata'):
-        fixed_tags.append('upstream-metadata-file-is-missing')
+        fixed_lintian_tag('source', 'upstream-metadata-file-is-missing')
 
     update_ordered_dict(
-        code, [(k, v.value) for (k, v) in changed.items()],
+        editor.code, [(k, v.value) for (k, v) in changed.items()],
         key=upstream_metadata_sort_key)
 
     # If there are only add-on-only fields, then just remove the file.
-    if not (set(code.keys()) - set(ADDON_ONLY_FIELDS)):
-        code.clear()
+    if not (set(editor.code.keys()) - set(ADDON_ONLY_FIELDS)):
+        editor.code.clear()
 
-    if code and not os.path.isdir('debian/upstream'):
+    if editor.code and not os.path.isdir('debian/upstream'):
         os.makedirs('debian/upstream', exist_ok=True)
 
 
@@ -143,5 +166,4 @@ fields = [
 
 report_result(
     'Set upstream metadata fields: %s.' % ', '.join(sorted(fields)),
-    fixed_lintian_tags=fixed_tags,
     certainty=achieved_certainty)
