@@ -5,8 +5,15 @@ import re
 import socket
 import sys
 from lintian_brush import USER_AGENT, DEFAULT_URLLIB_TIMEOUT
-from lintian_brush.control import ControlUpdater
-from lintian_brush.fixer import net_access_allowed
+from debmutate.control import ControlEditor
+from debmutate.vcs import (
+    get_vcs_info,
+    )
+from lintian_brush.fixer import (
+    net_access_allowed,
+    fixed_lintian_tag,
+    report_result,
+    )
 from lintian_brush.salsa import (
     determine_browser_url as determine_salsa_browser_url,
     guess_repository_url,
@@ -14,7 +21,6 @@ from lintian_brush.salsa import (
     )
 from lintian_brush.vcs import (
     determine_browser_url,
-    split_vcs_url,
     )
 from lintian_brush.vcswatch import VcsWatch, VcsWatchError
 from email.utils import parseaddr
@@ -34,29 +40,15 @@ def is_on_obsolete_host(url):
     return host in OBSOLETE_HOSTS
 
 
-def get_vcs_info(control):
-    if "Vcs-Git" in control:
-        repo_url, branch, subpath = split_vcs_url(control["Vcs-Git"])
-        return ("Git", repo_url)
-
-    if "Vcs-Bzr" in control:
-        return ("Bzr", control["Vcs-Bzr"])
-
-    if "Vcs-Svn" in control:
-        return ("Svn", control["Vcs-Svn"])
-
-    if "Vcs-Hg" in control:
-        repo_url, branch, subpath = split_vcs_url(control["Vcs-Hg"])
-        return ("Hg", repo_url)
-
-    return None, None
-
-
 def verify_salsa_repository(url):
     headers = {'User-Agent': USER_AGENT}
     browser_url = determine_salsa_browser_url(url)
-    response = urlopen(
-        Request(browser_url, headers=headers), timeout=DEFAULT_URLLIB_TIMEOUT)
+    try:
+        response = urlopen(
+            Request(browser_url, headers=headers),
+            timeout=DEFAULT_URLLIB_TIMEOUT)
+    except socket.timeout:
+        return None
     return response.status == 200
 
 
@@ -100,8 +92,9 @@ def find_new_urls(vcs_type, vcs_url, package, maintainer_email,
 
     # If possible, we use vcswatch to find the VCS repository URL
     if net_access:
+        loop = asyncio.get_event_loop()
         try:
-            (vcs_type, vcs_url, vcs_browser) = asyncio.run(
+            (vcs_type, vcs_url, vcs_browser) = loop.run_until_complete(
                 retrieve_vcswatch_urls(package))
         except VcsWatchError as e:
             sys.stderr.write('vcswatch URL unusable: %s\n' % e.args[0])
@@ -130,7 +123,7 @@ def find_new_urls(vcs_type, vcs_url, package, maintainer_email,
         vcs_type = "Git"
     # Verify that there is actually a repository there
     if net_access:
-        if not verify_salsa_repository(vcs_url):
+        if verify_salsa_repository(vcs_url) is False:
             raise NewRepositoryURLUnknown(vcs_type, vcs_url)
 
     print("Update Vcs-* headers to use salsa repository.")
@@ -139,11 +132,8 @@ def find_new_urls(vcs_type, vcs_url, package, maintainer_email,
     return (vcs_type, vcs_url, vcs_browser)
 
 
-fixed_tags = set()
-
-
 def migrate_from_obsolete_infra(control):
-    vcs_type, vcs_url = get_vcs_info(control)
+    vcs_type, vcs_url, unused_subpath = get_vcs_info(control)
     if vcs_type is None:
         return
     if not is_on_obsolete_host(vcs_url):
@@ -152,6 +142,9 @@ def migrate_from_obsolete_infra(control):
     package = control["Source"]
     maintainer_email = parseaddr(control["Maintainer"])[1]
 
+    old_vcs_browser = control.get('Vcs-Browser')
+    old_vcs_type = vcs_type
+    old_vcs_url = vcs_url
     try:
         (vcs_type, vcs_url, vcs_browser) = find_new_urls(
             vcs_type, vcs_url, package, maintainer_email,
@@ -159,15 +152,18 @@ def migrate_from_obsolete_infra(control):
     except NewRepositoryURLUnknown:
         return
 
-    fixed_tags.add("vcs-obsolete-in-debian-infrastructure")
+    fixed_lintian_tag(
+        'source', "vcs-obsolete-in-debian-infrastructure",
+        info='vcs-%s %s' % (old_vcs_type.lower(), old_vcs_url))
 
-    if "Vcs-Cvs" in control and re.match(
+    if (("Vcs-Cvs" in control and re.match(
             r"\@(?:cvs\.alioth|anonscm)\.debian\.org:/cvsroot/",
-            control["Vcs-Cvs"]):
-        fixed_tags.add("vcs-field-bitrotted")
-
-    if "Vcs-Svn" in control and "viewvc" in control["Vcs-Browser"]:
-        fixed_tags.add("vcs-field-bitrotted")
+            control["Vcs-Cvs"])) or
+        ("Vcs-Svn" in control and
+            "viewvc" in control["Vcs-Browser"])):
+        fixed_lintian_tag(
+            'source', "vcs-field-bitrotted",
+            info='%s %s' % (old_vcs_url or '', old_vcs_browser or ''))
 
     for hdr in ["Vcs-Git", "Vcs-Bzr", "Vcs-Hg", "Vcs-Svn"]:
         if hdr == "Vcs-" + vcs_type:
@@ -186,7 +182,7 @@ def migrate_from_obsolete_infra(control):
             pass
 
 
-with ControlUpdater() as updater:
+with ControlEditor() as updater:
     migrate_from_obsolete_infra(updater.source)
-if fixed_tags:
-    print("Fixed-Lintian-Tags: " + ", ".join(sorted(fixed_tags)))
+
+report_result()
