@@ -23,7 +23,7 @@ import itertools
 import re
 from typing import Optional, Tuple
 
-from breezy import osutils, version_info as breezy_version
+from breezy import osutils
 from breezy.branch import Branch
 from breezy.errors import NoSuchFile
 from breezy.tree import Tree
@@ -56,6 +56,7 @@ def gbp_conf_has_dch_section(tree: WorkingTree,
         return parser.has_section('dch')
 
 
+# TODO(jelmer): Use copy from debmutate.changelog
 def all_sha_prefixed(cl: Changelog) -> bool:
     sha_prefixed = 0
     for change in cl.changes():
@@ -140,18 +141,12 @@ def _changelog_stats(branch, history, subpath):
         except AttributeError:  # breezy <= 3.1.1
             get_deltas = branch.repository.get_deltas_for_revisions
         for delta in get_deltas(revs):
-            if breezy_version >= (3, 1):
-                filenames = set(
-                    [a.path[1] for a in delta.added] +
-                    [r.path[0] for r in delta.removed] +
-                    [r.path[0] for r in delta.renamed] +
-                    [r.path[1] for r in delta.renamed] +
-                    [m.path[0] for m in delta.modified])
-            else:
-                filenames = set([a[0] for a in delta.added] +
-                                [r[0] for r in delta.removed] +
-                                [r[1] for r in delta.renamed] +
-                                [m[0] for m in delta.modified])
+            filenames = set(
+                [a.path[1] for a in delta.added] +
+                [r.path[0] for r in delta.removed] +
+                [r.path[0] for r in delta.renamed] +
+                [r.path[1] for r in delta.renamed] +
+                [m.path[0] for m in delta.modified])
             if not set([
                     f for f in filenames
                     if f.startswith(osutils.pathjoin(subpath, 'debian/'))]):
