@@ -15,13 +15,48 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-"""Functions for working with upstream metadata."""
+"""Functions for working with upstream metadata.
+
+This gathers information about upstreams from various places.
+Each bit of information gathered is wrapped in a UpstreamDatum
+object, which contains the field name.
+
+The fields used here match those in https://wiki.debian.org/UpstreamMetadata
+
+Supported fields:
+- Homepage
+- Name
+- Contact
+- Repository
+- Repository-Browse
+- Bug-Database
+- Bug-Submit
+- Screenshots
+- Archive
+
+Extensions for lintian-brush.
+- X-SourceForge-Project
+- X-Wiki
+- X-Summary
+- X-Description
+- X-License
+- X-Copyright
+
+Supported, but unused.
+- FAQ
+- Donation
+- Documentation
+- Registration
+- Security-Contact
+- Webservice
+"""
 
 import json
 import os
 import re
 import socket
 import urllib.error
+from typing import Optional
 from urllib.parse import quote, urlparse, urlunparse, urljoin, parse_qs
 from warnings import warn
 
@@ -43,6 +78,7 @@ from lintian_brush import (
 from lintian_brush.vcs import (
     browse_url_from_repo_url,
     plausible_url as plausible_vcs_url,
+    plausible_browse_url as plausible_vcs_browse_url,
     sanitize_url as sanitize_vcs_url,
     is_gitlab_site,
     )
@@ -86,38 +122,11 @@ class UpstreamDatum(object):
             self.origin)
 
 
-# See https://wiki.debian.org/UpstreamMetadata
-# Supported fields:
-# - Homepage
-# - Name
-# - Contact
-# - Repository
-# - Repository-Browse
-# - Bug-Database
-# - Bug-Submit
-# - Screenshots
-# - Archive
-# - X-SourceForge-Project
-# - X-Wiki
-# - X-Summary
-# - X-Description
-# - X-License
-# - X-Copyright
-
-# Supported, but unused.
-# - FAQ
-# - Donation
-# - Documentation
-# - Registration
-# - Security-Contact
-# - Webservice
-
-
-def _load_json_url(http_url):
+def _load_json_url(http_url: str, timeout: int = DEFAULT_URLLIB_TIMEOUT):
     headers = {'User-Agent': USER_AGENT, 'Accept': 'application/json'}
     http_contents = urlopen(
         Request(http_url, headers=headers),
-        timeout=DEFAULT_URLLIB_TIMEOUT).read()
+        timeout=timeout).read()
     return json.loads(http_contents)
 
 
@@ -231,6 +240,14 @@ def known_bad_guess(datum):
             return True
         if parsed_url.hostname == 'bugs.freedesktop.org':
             return True
+    if datum.field == 'Repository':
+        parsed_url = urlparse(datum.value)
+        if parsed_url.hostname == 'anongit.kde.org':
+            return True
+    if datum.field == 'Repository-Browse':
+        parsed_url = urlparse(datum.value)
+        if parsed_url.hostname == 'cgit.kde.org':
+            return True
     if datum.value.lower() == 'unknown':
         return True
     return False
@@ -272,13 +289,13 @@ def guess_from_debian_rules(path, trust_package):
         pass
     else:
         yield UpstreamDatum(
-            "Repository", sanitize_vcs_url(upstream_git.decode()), "certain")
+            "Repository", sanitize_vcs_url(upstream_git.decode()), "likely")
     try:
         upstream_url = mf.get_variable(b'DEB_UPSTREAM_URL')
     except KeyError:
         pass
     else:
-        yield UpstreamDatum("X-Download", upstream_url.decode(), "certain")
+        yield UpstreamDatum("X-Download", upstream_url.decode(), "likely")
 
 
 def guess_from_debian_watch(path, trust_package):
@@ -543,36 +560,55 @@ def guess_from_debian_copyright(path, trust_package):
             yield UpstreamDatum(
                 "Bug-Database", header["X-Upstream-Bugs"], 'certain')
         if "X-Source-Downloaded-From" in header:
-            yield UpstreamDatum(
-                "Repository",
-                guess_repo_from_url(header["X-Source-Downloaded-From"]),
-                'certain')
+            url = guess_repo_from_url(header["X-Source-Downloaded-From"])
+            if url is not None:
+                yield UpstreamDatum("Repository", url, 'certain')
+
+
+def url_from_git_clone_command(command):
+    import shlex
+    argv = shlex.split(command.decode('utf-8', 'replace'))
+    args = [arg for arg in argv if arg.strip()]
+    i = 0
+    while i < len(args):
+        if not args[i].startswith('-'):
+            i += 1
+            continue
+        if '=' in args[i]:
+            del args[i]
+            continue
+        # arguments that take a parameter
+        if args[i] in ('-b', '--depth', '--branch'):
+            del args[i]
+            del args[i]
+            continue
+        del args[i]
+    try:
+        url = args[2]
+    except IndexError:
+        url = args[0]
+    if plausible_vcs_url(url):
+        return sanitize_vcs_url(url)
+    return None
 
 
 def guess_from_readme(path, trust_package):
-    import shlex
     urls = []
     try:
         with open(path, 'rb') as f:
             lines = list(f.readlines())
             for i, line in enumerate(lines):
                 line = line.strip()
-                if line.strip().lstrip(b'$').strip().startswith(b'git clone'):
+                if line.strip().lstrip(b'$').strip().startswith(b'git clone '):
                     line = line.strip().lstrip(b'$').strip()
                     while line.endswith(b'\\'):
                         line += lines[i+1]
                         line = line.strip()
                         i += 1
-                    argv = shlex.split(line.decode('utf-8', 'replace'))
-                    args = [arg for arg in argv[2:]
-                            if not arg.startswith('-') and arg.strip()]
-                    try:
-                        url = args[-2]
-                    except IndexError:
-                        url = args[0]
-                    if plausible_vcs_url(url):
-                        urls.append(sanitize_vcs_url(url))
-                project_re = b'([^/]+)/([^/?.()">\\s]*[^-/?.()">\\s])'
+                    url = url_from_git_clone_command(line)
+                    if url:
+                        urls.append(url)
+                project_re = b'([^/]+)/([^/?.()"#>\\s]*[^-/?.()"#>\\s])'
                 for m in re.finditer(
                         b'https://travis-ci.org/' + project_re, line):
                     yield UpstreamDatum(
@@ -609,7 +645,7 @@ def guess_from_readme(path, trust_package):
                         'Repository',
                         line.strip().rstrip(b'.').decode(), 'possible')
                 for m in re.finditer(
-                        b'https://([^/]+)/([^\\s()"]+)', line):
+                        b'https://([^/]+)/([^\\s()"#]+)', line):
                     if is_gitlab_site(m.group(1).decode()):
                         yield UpstreamDatum(
                             'Repository',
@@ -816,11 +852,13 @@ def guess_from_cabal(path, trust_package=False):
             'certain')
 
 
-def is_email_address(value):
+def is_email_address(value: str) -> bool:
     return '@' in value or ' (at) ' in value
 
 
 def guess_from_configure(path, trust_package=False):
+    if os.path.isdir(path):
+        return
     with open(path, 'rb') as f:
         for line in f:
             if b'=' not in line:
@@ -979,7 +1017,8 @@ def guess_from_pom_xml(path, trust_package=False):
                 url = url_tag.text.split(':', 2)[2]
             else:
                 url = url_tag.text
-            yield UpstreamDatum('Repository-Browse', url, 'certain')
+            if plausible_vcs_browse_url(url):
+                yield UpstreamDatum('Repository-Browse', url, 'certain')
         connection_tag = scm_tag.find('connection')
         if connection_tag is not None:
             connection = connection_tag.text
@@ -1023,6 +1062,15 @@ def guess_from_git_config(path, trust_package=False):
     # TODO(jelmer): Try origin?
 
 
+def guess_from_get_orig_source(path, trust_package=False):
+    with open(path, 'rb') as f:
+        for line in f:
+            if line.startswith(b'git clone'):
+                url = url_from_git_clone_command(line)
+                if url:
+                    yield UpstreamDatum('Repository', url, 'likely')
+
+
 def _get_guessers(path, trust_package=False):
     CANDIDATES = [
         ('debian/watch', guess_from_debian_watch),
@@ -1040,6 +1088,7 @@ def _get_guessers(path, trust_package=False):
         ('Cargo.toml', guess_from_cargo),
         ('pom.xml', guess_from_pom_xml),
         ('.git/config', guess_from_git_config),
+        ('debian/get-orig-source.sh', guess_from_get_orig_source),
         ]
 
     # Search for something Python-y
@@ -1078,7 +1127,7 @@ def _get_guessers(path, trust_package=False):
     readme_filenames = [
         n for n in os.listdir(path)
         if any([n.startswith(p)
-                for p in ['README', 'HACKING', 'CONTRIBUTING']])
+                for p in ['readme', 'README', 'HACKING', 'CONTRIBUTING']])
         and os.path.splitext(n)[1] not in ('.html', '.pdf', '.xml')]
     CANDIDATES.extend([(n, guess_from_readme) for n in readme_filenames])
 
@@ -1285,9 +1334,9 @@ def extract_sf_project_name(url):
     m = re.fullmatch('https?://(.*).(sf|sourceforge).net/?', url)
     if m:
         return m.group(1)
-    m = re.match('https://sourceforge.net/projects/([^/]+)', url)
+    m = re.match('https://sourceforge.net/(projects|p)/([^/]+)', url)
     if m:
-        return m.group(1)
+        return m.group(2)
 
 
 def repo_url_from_merge_request_url(url):
@@ -1372,6 +1421,15 @@ def bug_database_url_from_bug_submit_url(url):
             path_elements.pop(-1)
         return urlunparse(
             parsed_url._replace(path='/'.join(path_elements)))
+    if parsed_url.hostname == 'sourceforge.net':
+        if len(path_elements) < 3:
+            return None
+        if path_elements[0] != 'p' or path_elements[2] != 'bugs':
+            return None
+        if len(path_elements) > 3:
+            path_elements.pop(-1)
+        return urlunparse(
+            parsed_url._replace(path='/'.join(path_elements)))
     return None
 
 
@@ -1400,14 +1458,15 @@ def bug_submit_url_from_bug_database_url(url):
     return None
 
 
-def verify_repository_url(url, version=None):
+def verify_repository_url(url: str, version: Optional[str] = None) -> bool:
+    """Verify whether a repository URL is valid."""
     parsed_url = urlparse(url)
     if parsed_url.netloc == 'github.com':
         path_elements = parsed_url.path.strip('/').split('/')
-        if path_elements[1].endswith('.git'):
-            path_elements[1] = path_elements[1][:-4]
         if len(path_elements) < 2:
             return False
+        if path_elements[1].endswith('.git'):
+            path_elements[1] = path_elements[1][:-4]
         api_url = 'https://api.github.com/repos/%s/%s' % (
             path_elements[0], path_elements[1])
         try:
@@ -1610,13 +1669,20 @@ def extend_upstream_metadata(upstream_metadata, path, minimum_certainty=None,
                              consult_external_directory=False):
     """Extend a set of upstream metadata.
     """
-    if 'Homepage' in upstream_metadata:
-        project = extract_sf_project_name(upstream_metadata['Homepage'].value)
+    # TODO(jelmer): Use EXTRAPOLATE_FNS mechanism for this?
+    for field in ['Homepage', 'Bug-Database', 'Bug-Submit', 'Repository',
+                  'Repository-Browse', 'X-Download']:
+        if field not in upstream_metadata:
+            continue
+        project = extract_sf_project_name(upstream_metadata[field].value)
         if project:
+            certainty = min_certainty(
+                ['likely', upstream_metadata[field].certainty])
             upstream_metadata['Archive'] = UpstreamDatum(
-                'Archive', 'SourceForge', 'likely')
+                'Archive', 'SourceForge', certainty)
             upstream_metadata['X-SourceForge-Project'] = UpstreamDatum(
-                'X-SourceForge-Project', project, 'likely')
+                'X-SourceForge-Project', project, certainty)
+            break
 
     archive = upstream_metadata.get('Archive')
     if (archive and archive.value == 'SourceForge' and
@@ -1776,7 +1842,14 @@ def parse_pkgbuild_variables(f):
     import shlex
     variables = {}
     keep = None
+    existing = None
     for line in f:
+        if existing:
+            line = existing + line
+        if line.endswith(b'\\\n'):
+            existing = line[:-2]
+            continue
+        existing = None
         if (line.startswith(b'\t') or line.startswith(b' ') or
                 line.startswith(b'#')):
             continue
@@ -1847,7 +1920,7 @@ def guess_from_pecl_url(url):
             yield 'Homepage', tag.attrs['href']
 
 
-def guess_from_aur(package):
+def guess_from_aur(package: str):
     vcses = ['git', 'bzr', 'hg']
     for vcs in vcses:
         url = (
