@@ -26,11 +26,19 @@ __all__ = [
 
 import posixpath
 import re
+import socket
 from typing import Optional
+import urllib.error
 from urllib.parse import urlparse, urlunparse, ParseResult
+from urllib.request import urlopen, Request
 
 from debmutate.vcs import split_vcs_url, unsplit_vcs_url
 
+from lintian_brush import (
+    USER_AGENT,
+    DEFAULT_URLLIB_TIMEOUT,
+    )
+
 
 KNOWN_GITLAB_SITES = [
     'gitlab.com',
@@ -38,12 +46,37 @@ KNOWN_GITLAB_SITES = [
     'gitlab.gnome.org',
     'gitlab.freedesktop.org',
     'gitlab.labs.nic.cz',
+    'invent.kde.org',
     ]
 
 
+def probe_gitlab_host(hostname: str):
+    headers = {'User-Agent': USER_AGENT, 'Accept': 'application/json'}
+    try:
+        urlopen(
+            Request('https://%s/api/v4/version' % hostname, headers=headers),
+            timeout=DEFAULT_URLLIB_TIMEOUT)
+    except urllib.error.HTTPError as e:
+        if e.status == 401:
+            import json
+            if json.loads(e.read()) == {"message": "401 Unauthorized"}:
+                return True
+    except (socket.timeout, urllib.error.URLError):
+        # Probably not?
+        return False
+    return False
+
+
 def is_gitlab_site(hostname: str, net_access: bool = False) -> bool:
-    # TODO(jelmer): Try API to see if this is a gitlab site
-    return hostname in KNOWN_GITLAB_SITES
+    if hostname is None:
+        return False
+    if hostname in KNOWN_GITLAB_SITES:
+        return True
+    if hostname.startswith('gitlab.'):
+        return True
+    if net_access:
+        return probe_gitlab_host(hostname)
+    return False
 
 
 def find_public_vcs_url(url: str) -> Optional[str]:
@@ -100,6 +133,10 @@ def plausible_url(url: str) -> bool:
     return ':' in url
 
 
+def plausible_browse_url(url: str) -> bool:
+    return url.startswith('https://') or url.startswith('http://')
+
+
 def fix_path_in_port(parsed: ParseResult, branch: Optional[str]):
     if ':' not in parsed.netloc or parsed.netloc.endswith(']'):
         return None, None
@@ -179,6 +216,13 @@ def fix_git_gnome_org_url(parsed, branch):
     return None, None
 
 
+def fix_anongit_url(parsed, branch):
+    if parsed.netloc == 'anongit.kde.org' and parsed.scheme == 'git':
+        parsed = parsed._replace(scheme='https')
+        return parsed, branch
+    return None, None
+
+
 def fix_freedesktop_org_url(parsed: ParseResult, branch: Optional[str]):
     if parsed.netloc == 'anongit.freedesktop.org':
         path = parsed.path
@@ -201,6 +245,7 @@ FIXERS = [
     drop_git_username,
     fix_branch_argument,
     fix_git_gnome_org_url,
+    fix_anongit_url,
     fix_freedesktop_org_url,
     ]
 
@@ -407,8 +452,11 @@ def find_secure_vcs_url(url: str, net_access: bool = True) -> Optional[str]:
             scheme='https', netloc='code.launchpad.net')
 
     if parsed_repo_url.hostname in ('git.savannah.gnu.org', 'git.sv.gnu.org'):
-        parsed_repo_url = parsed_repo_url._replace(
-            scheme='https', path='/git' + parsed_repo_url.path)
+        if parsed_repo_url.scheme == 'http':
+            parsed_repo_url = parsed_repo_url._replace(scheme='https')
+        else:
+            parsed_repo_url = parsed_repo_url._replace(
+                scheme='https', path='/git' + parsed_repo_url.path)
 
     if net_access:
         secure_repo_url = parsed_repo_url._replace(scheme='https')
